@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary::Hash;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.014';
+our $VERSION   = '0.015';
 
 use Sub::HandlesVia::HandlerLibrary;
 our @ISA = 'Sub::HandlesVia::HandlerLibrary';
@@ -15,7 +15,7 @@ use Types::Standard qw( HashRef ArrayRef Optional Str CodeRef Item Any Ref Defin
 
 our @METHODS = qw( all accessor clear count defined delete elements exists get
 	is_empty keys kv set shallow_clone values sorted_keys
-	for_each_pair for_each_key for_each_value );
+	for_each_pair for_each_key for_each_value reset );
 
 sub _type_inspector {
 	my ($me, $type) = @_;
@@ -293,4 +293,12 @@ sub for_each_value {
 		template  => 'for my $shv_value (values %{$GET}) { &{$ARG}($shv_value) }; $SELF',
 }
 
+sub reset {
+	handler
+		name      => 'Hash:reset',
+		args      => 0,
+		template  => '« $DEFAULT »',
+		default_for_reset => sub { '{}' },
+}
+
 1;
